Index: src/arm/macro-assembler-arm.h |
diff --git a/src/arm/macro-assembler-arm.h b/src/arm/macro-assembler-arm.h |
index f6673ca1a5a27ef20a9242efa22d463ddb867b0a..057591af35c55c7dad06edb69418c3ccb534833b 100644 |
--- a/src/arm/macro-assembler-arm.h |
+++ b/src/arm/macro-assembler-arm.h |
@@ -753,32 +753,25 @@ class MacroAssembler: public Assembler { |
Register scratch2, |
Register scratch3, |
Label* gc_required); |
- void AllocateAsciiString(Register result, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Register scratch3, |
- Label* gc_required); |
+ void AllocateOneByteString(Register result, Register length, |
+ Register scratch1, Register scratch2, |
+ Register scratch3, Label* gc_required); |
void AllocateTwoByteConsString(Register result, |
Register length, |
Register scratch1, |
Register scratch2, |
Label* gc_required); |
- void AllocateAsciiConsString(Register result, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Label* gc_required); |
+ void AllocateOneByteConsString(Register result, Register length, |
+ Register scratch1, Register scratch2, |
+ Label* gc_required); |
void AllocateTwoByteSlicedString(Register result, |
Register length, |
Register scratch1, |
Register scratch2, |
Label* gc_required); |
- void AllocateAsciiSlicedString(Register result, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Label* gc_required); |
+ void AllocateOneByteSlicedString(Register result, Register length, |
+ Register scratch1, Register scratch2, |
+ Label* gc_required); |
// Allocates a heap number or jumps to the gc_required label if the young |
// space is full and a scavenge is needed. All registers are clobbered also |
@@ -1321,36 +1314,31 @@ class MacroAssembler: public Assembler { |
Register scratch3, |
Label* not_found); |
// Checks if both objects are sequential ASCII strings and jumps to label |
// if either is not. Assumes that neither object is a smi. |
- void JumpIfNonSmisNotBothSequentialAsciiStrings(Register object1, |
- Register object2, |
- Register scratch1, |
- Register scratch2, |
- Label* failure); |
+ void JumpIfNonSmisNotBothSequentialOneByteStrings(Register object1, |
+ Register object2, |
+ Register scratch1, |
+ Register scratch2, |
+ Label* failure); |
- // Checks if both objects are sequential ASCII strings and jumps to label |
+ // Checks if both objects are sequential one-byte strings and jumps to label |
// if either is not. |
- void JumpIfNotBothSequentialAsciiStrings(Register first, |
- Register second, |
- Register scratch1, |
- Register scratch2, |
- Label* not_flat_ascii_strings); |
+ void JumpIfNotBothSequentialOneByteStrings(Register first, Register second, |
+ Register scratch1, |
+ Register scratch2, |
+ Label* not_flat_one_byte_strings); |
- // Checks if both instance types are sequential ASCII strings and jumps to |
+ // Checks if both instance types are sequential one-byte strings and jumps to |
// label if either is not. |
- void JumpIfBothInstanceTypesAreNotSequentialAscii( |
- Register first_object_instance_type, |
- Register second_object_instance_type, |
- Register scratch1, |
- Register scratch2, |
- Label* failure); |
- |
- // Check if instance type is sequential ASCII string and jump to label if |
+ void JumpIfBothInstanceTypesAreNotSequentialOneByte( |
+ Register first_object_instance_type, Register second_object_instance_type, |
+ Register scratch1, Register scratch2, Label* failure); |
+ |
+ // Check if instance type is sequential one-byte string and jump to label if |
// it is not. |
- void JumpIfInstanceTypeIsNotSequentialAscii(Register type, |
- Register scratch, |
- Label* failure); |
+ void JumpIfInstanceTypeIsNotSequentialOneByte(Register type, Register scratch, |
+ Label* failure); |
void JumpIfNotUniqueName(Register reg, Label* not_unique_name); |
@@ -1321,36 +1314,31 @@ class MacroAssembler: public Assembler { |
Register scratch3, |
Label* not_found); |
- // Checks if both objects are sequential ASCII strings and jumps to label |
+ // Checks if both objects are sequential one-byte strings and jumps to label |
// if either is not. Assumes that neither object is a smi. |